package img;

import java.awt.Image;
import java.awt.image.BufferedImage;

/**
 * This interface provisions for the basic methods that are needed when dealing
 * with a digital picture. A digital picture can be created in three ways: from
 * a file name, from another image, or from a width and height specification. A
 * digital picture has accessor and mutator methods for its pixels. A digital
 * picture can be displayed graphically. A digital picture has an associated
 * string which serves as the picture's title.
 * 
 * A digital picture has a rectangular grid of pixels.
 * 
 */
public interface AbstractDigitalPicture {

	/**
	 * Get the name of the file associated with this digital picture, if one
	 * exists. The digital picture may not have been created from a file, in
	 * which case this method returns null.
	 * 
	 * @return as described above
	 */
	public String getFileName();

	/**
	 * Get the string that encapsulates the title that is associated with this
	 * digital picture.
	 * 
	 * @return as described above
	 */
	public String getTitle();

	/**
	 * Set the string that encapsulates the title that is associated with this
	 * digital picture.
	 * 
	 */
	public void setTitle(String title);

	/**
	 * Returns the width of this picture in pixels.
	 * 
	 * @return as described above.
	 */
	public int getWidth();

	/**
	 * Returns the height of this picture in pixels.
	 * 
	 * @return as described above.
	 */
	public int getHeight();

	/**
	 * Returns the Image from the picture
	 * 
	 * @return as described above.
	 */
	public Image getImage();

	/**
	 * Returns the BufferedImage from the picture
	 * 
	 * @return as described above.
	 */
	public BufferedImage getBufferedImage();

	/**
	 * Returns the colour information about the specified pixel, as encoded in
	 * an int value.
	 * 
	 * @param x
	 *            the x position of the pixel
	 * @param y
	 *            the y position of the pixel
	 * @return as described above
	 */
	public int getBasicPixel(int x, int y); // get the pixel information as an
											// int

	/**
	 * Sets the colour of the specified pixel, as encoded in the passed int
	 * value.
	 * 
	 * @param x
	 *            the x position of the pixel
	 * @param y
	 *            the y position of the pixel
	 */
	public void setBasicPixel(int x, int y, int rgb);

	/**
	 * Returns the Pixel object at the specified (x,y) coordinate.
	 * 
	 * @param x
	 *            the x position of the pixel
	 * @param y
	 *            the y position of the pixel
	 * @return as descibed above
	 */
	public Pixel getPixel(int x, int y); // get the pixel information as an
											// object

	public void load(Image image); // load the image into the picture

	/**
	 * Reads the image from the passed filename and construct a corresponding
	 * digital picture.
	 * 
	 * @param fileName
	 *            as described above
	 * @throws Exception
	 *             if the contents of the passed filename cannot be understood
	 *             as a image.
	 */
	public void load(String fileName) throws Exception;

	/**
	 * Invokes functionality to show this picture on the graphical display.
	 */
	public void show();
}